@@ -82,7 +82,7 @@ void CfgTerminalEmulator::save(KConfig *)
 {
 	KConfigGroup config(KSharedConfig::openConfig("kdeglobals"), "General");
 	const QString terminal = terminalCB->isChecked() ? "konsole" : terminalLE->text();
-	config.writePathEntry("TerminalApplication", terminal, KConfig::Normal|KConfig::Global);
+	config.writePathEntry("TerminalApplication", terminal); // KConfig::Normal|KConfig::Global);
 	config.sync();
 
 	KGlobalSettings::self()->emitChange(KGlobalSettings::SettingsChanged);
