@@ -32,6 +32,7 @@
 
 #include <kconfig.h>
 #include <kconfiggroup.h>
+#include <kdialog.h>
 #include <kglobal.h>
 #include <kicon.h>
 #include <klocale.h>
@@ -70,7 +71,7 @@ TrashConfigModule::TrashConfigModule( QWidget* parent, const QVariantList& )
              this, SLOT( percentChanged( double ) ) );
     connect( mPercent, SIGNAL( valueChanged( double ) ),
              this, SLOT( changed() ) );
-    connect( mLimitReachedAction, SIGNAL( activated( int ) ),
+    connect( mLimitReachedAction, SIGNAL( currentIndexChanged( int ) ),
              this, SLOT( changed() ) );
 
     trashChanged( 0 );
@@ -134,7 +135,10 @@ void TrashConfigModule::percentChanged( double percent )
         size = size/1024.0;
     }
 
-    mSizeLabel->setText( i18n( "(%1 %2)", QString::number( size, 'f', 2 ), unit ) );
+    mSizeLabel->setText(
+    ki18nc( "%1 is amount of disk space, %2 the unit, KBytes, MBytes, GBytes, TBytes, etc.", "(%1 %2)" )
+    .subs( size, -1, 'f', 2 ).subs( unit ).toString()
+    );
 }
 
 void TrashConfigModule::trashChanged( QListWidgetItem *item )
@@ -232,8 +236,8 @@ void TrashConfigModule::writeConfig()
 void TrashConfigModule::setupGui()
 {
     QVBoxLayout *layout = new QVBoxLayout( this );
-    layout->setMargin( 11 );
-    layout->setSpacing( 6 );
+    layout->setMargin( KDialog::marginHint() );
+    layout->setSpacing( KDialog::spacingHint() );
 
     TrashImpl::TrashDirMap map = mTrashImpl->trashDirectories();
     if ( map.count() != 1 ) {
@@ -264,49 +268,64 @@ void TrashConfigModule::setupGui()
     layout->addLayout( daysLayout );
 
     mUseTimeLimit = new QCheckBox( i18n( "Delete files older than:" ), this );
+    mUseTimeLimit->setWhatsThis( i18nc( "@info:whatsthis",
+                                     "<para>Check this box to allow <b>automatic deletion</b> of files that are older than the value specified. "
+                                     "Leave this disabled to <b>not</b> automatically delete any items after a certain timespan</para>" ) );
     daysLayout->addWidget( mUseTimeLimit );
     mDays = new QSpinBox( this );
     connect( mDays, SIGNAL( valueChanged( int ) ), this, SLOT( updateSpinBoxSuffix( int ) ) );
     
     mDays->setRange( 1, 365 );
     mDays->setSingleStep( 1 );
-    mDays->setSuffix( QString(" ") + i18np("day", "days", mDays->value()) );
+    mDays->setSuffix( i18np(" day", " days", mDays->value()) );
+    mDays->setWhatsThis( i18nc( "@info:whatsthis",
+                                     "<para>Set the number of days that files can remain in the trash. "
+                                     "Any files older than this will be automatically deleted.</para>" ) );
     daysLayout->addWidget( mDays );
 
     QGridLayout *sizeLayout = new QGridLayout();
     layout->addLayout( sizeLayout );
 
     mUseSizeLimit = new QCheckBox( i18n( "Limit to maximum size" ), this );
+    mUseSizeLimit->setWhatsThis( i18nc( "@info:whatsthis",
+                                     "<para>Check this box to limit the trash to the maximum amount of disk space that you specify below. "
+                                     "Otherwise, it will be unlimited.</para>" ) );
     sizeLayout->addWidget( mUseSizeLimit, 0, 0, 1, 2 );
 
     mSizeWidget = new QWidget( this );
-    sizeLayout->setColumnMinimumWidth( 0, 30 );
     sizeLayout->addWidget( mSizeWidget, 1, 1 );
 
     QGridLayout *sizeWidgetLayout = new QGridLayout( mSizeWidget );
-    sizeWidgetLayout->setMargin( 11 );
-    sizeWidgetLayout->setSpacing( 6 );
+    sizeWidgetLayout->setMargin( 0 );
+    sizeWidgetLayout->setSpacing( KDialog::spacingHint() );
 
     QLabel *label = new QLabel( i18n( "Maximum size:" ), mSizeWidget );
-    sizeWidgetLayout->addWidget( label, 0, 0 );
+    sizeWidgetLayout->addWidget( label, 0, 0, Qt::AlignRight );
 
     mPercent = new QDoubleSpinBox( mSizeWidget );
     mPercent->setRange( 0.001, 100 );
     mPercent->setDecimals( 3 );
     mPercent->setSingleStep( 1 );
     mPercent->setSuffix( " %" );
+    mPercent->setWhatsThis( i18nc( "@info:whatsthis",
+                                     "<para>This is the maximum percent of disk space that will be used for the trash.</para>" ) );
     sizeWidgetLayout->addWidget( mPercent, 0, 1 );
 
     mSizeLabel = new QLabel( mSizeWidget );
+    mSizeLabel->setWhatsThis( i18nc( "@info:whatsthis",
+                                     "<para>This is the calculated amount of disk space that will be allowed for the trash, the maximum.</para>" ) );
     sizeWidgetLayout->addWidget( mSizeLabel, 0, 2 );
 
     label = new QLabel( i18n( "When limit reached:" ), mSizeWidget );
-    sizeWidgetLayout->addWidget( label, 1, 0 );
+    sizeWidgetLayout->addWidget( label, 1, 0, Qt::AlignRight );
 
     mLimitReachedAction = new QComboBox( mSizeWidget );
     mLimitReachedAction->addItem( i18n( "Warn Me" ) );
     mLimitReachedAction->addItem( i18n( "Delete Oldest Files From Trash" ) );
     mLimitReachedAction->addItem( i18n( "Delete Biggest Files From Trash" ) );
+    mLimitReachedAction->setWhatsThis( i18nc( "@info:whatsthis",
+                                              "<para>When the size limit is reached, it will prefer to delete the type of files that you specify, first. "
+                                              "If this is set to warn you, it will do so instead of automatically deleting files.</para>" ) );
     sizeWidgetLayout->addWidget( mLimitReachedAction, 1, 1, 1, 2 );
 
     layout->addStretch();
@@ -314,7 +333,7 @@ void TrashConfigModule::setupGui()
 
 void TrashConfigModule::updateSpinBoxSuffix( int interval )
 {
-    mDays->setSuffix( QString(" ") + i18np( "day", "days", interval ) );
+    mDays->setSuffix( i18np( " day", " days", interval ) );
 }
 
 #include "kcmtrash.moc"
